==> mx-packageinstaller-pkglist_19.05.06.tar.xz: mx-packageinstaller-pkglist/albanian_thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Albanian_Thunderbird
</name>

<description>
   <am>Albanian localisation of Thunderbird</am>
   <ar>Albanian localisation of Thunderbird</ar>
   <bg>Albanian localisation of Thunderbird</bg>
   <ca>Localització de Thunderbird en Albanès</ca>
   <cs>Albanian localisation of Thunderbird</cs>
   <da>Albansk oversættelse af Thunderbird</da>
   <de>Albanische Lokalisierung von Thunderbird</de>
   <el>Αλβανικός εντοπισμός του Thunderbird</el>
   <en>Albanian localisation of Thunderbird</en>
   <es>Localización Albania de Thunderbird</es>
   <et>Albanian localisation of Thunderbird</et>
   <eu>Albanian localisation of Thunderbird</eu>
   <fa>Albanian localisation of Thunderbird</fa>
   <fi>Albanian localisation of Thunderbird</fi>
   <fr>Localisation albanaise pour Thunderbird</fr>
   <he_IL>Albanian localisation of Thunderbird</he_IL>
   <hi>Albanian localisation of Thunderbird</hi>
   <hr>Albanska lokalizacija Thunderbirda</hr>
   <hu>Albanian localisation of Thunderbird</hu>
   <id>Albanian localisation of Thunderbird</id>
   <is>Albanian localisation of Thunderbird</is>
   <it>Localizzazione albanese di Thunderbird</it>
   <ja_JP>Albanian localisation of Thunderbird</ja_JP>
   <ja>Albanian localisation of Thunderbird</ja>
   <kk>Albanian localisation of Thunderbird</kk>
   <ko>Albanian localisation of Thunderbird</ko>
   <lt>Albanian localisation of Thunderbird</lt>
   <mk>Albanian localisation of Thunderbird</mk>
   <nb>Albanian localisation of Thunderbird</nb>
   <nl>Albanese lokalisatie van Thunderbird</nl>
   <pl>Albańska lokalizacja Thunderbirda</pl>
   <pt_BR>Albanês Localização para Thunderbird</pt_BR>
   <pt>Albanês Localização para Thunderbird</pt>
   <ro>Albanian localisation of Thunderbird</ro>
   <ru>Albanian localisation of Thunderbird</ru>
   <sk>Albanian localisation of Thunderbird</sk>
   <sl>Albanian localisation of Thunderbird</sl>
   <sq>Albanian localisation of Thunderbird</sq>
   <sr>Albanian localisation of Thunderbird</sr>
   <sv>Albansk lokalisering av Thunderbird</sv>
   <tr>Albanian localisation of Thunderbird</tr>
   <uk>Albanian локалізація Thunderbird</uk>
   <zh_CN>Albanian localisation of Thunderbird</zh_CN>
   <zh_TW>Albanian localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
thunderbird-l10n-sq
lightning-l10n-sq
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
thunderbird-l10n-sq
lightning-l10n-sq
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.02.tar.xz: mx-packageinstaller-pkglist/albanian_thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Albanian_Thunderbird
</name>

<description>
   <am>Albanian localisation of Thunderbird</am>
   <ar>Albanian localisation of Thunderbird</ar>
   <bg>Albanian localisation of Thunderbird</bg>
   <ca>Localització de Thunderbird en Albanès</ca>
   <cs>Albanian localisation of Thunderbird</cs>
   <da>Albansk oversættelse af Thunderbird</da>
   <de>Albanische Lokalisierung von Thunderbird</de>
   <el>Αλβανικός εντοπισμός του Thunderbird</el>
   <en>Albanian localisation of Thunderbird</en>
   <es>Localización Albania de Thunderbird</es>
   <et>Albanian localisation of Thunderbird</et>
   <eu>Albanian localisation of Thunderbird</eu>
   <fa>Albanian localisation of Thunderbird</fa>
   <fi>Albanian localisation of Thunderbird</fi>
   <fr>Localisation albanaise pour Thunderbird</fr>
   <he_IL>Albanian localisation of Thunderbird</he_IL>
   <hi>Albanian localisation of Thunderbird</hi>
   <hr>Albanska lokalizacija Thunderbirda</hr>
   <hu>Albanian localisation of Thunderbird</hu>
   <id>Albanian localisation of Thunderbird</id>
   <is>Albanian localisation of Thunderbird</is>
   <it>Localizzazione albanese di Thunderbird</it>
   <ja_JP>Albanian localisation of Thunderbird</ja_JP>
   <ja>Albanian localisation of Thunderbird</ja>
   <kk>Albanian localisation of Thunderbird</kk>
   <ko>Albanian localisation of Thunderbird</ko>
   <lt>Albanian localisation of Thunderbird</lt>
   <mk>Albanian localisation of Thunderbird</mk>
   <nb>Albanian localisation of Thunderbird</nb>
   <nl>Albanese lokalisatie van Thunderbird</nl>
   <pl>Albańska lokalizacja Thunderbirda</pl>
   <pt_BR>Albanês Localização para Thunderbird</pt_BR>
   <pt>Albanês Localização para Thunderbird</pt>
   <ro>Albanian localisation of Thunderbird</ro>
   <ru>Albanian localisation of Thunderbird</ru>
   <sk>Albanian lokalizácia pre Thunderbird</sk>
   <sl>Albanian localisation of Thunderbird</sl>
   <sq>Albanian localisation of Thunderbird</sq>
   <sr>Albanian localisation of Thunderbird</sr>
   <sv>Albansk lokalisering av Thunderbird</sv>
   <tr>Albanian localisation of Thunderbird</tr>
   <uk>Albanian локалізація Thunderbird</uk>
   <zh_CN>Albanian localisation of Thunderbird</zh_CN>
   <zh_TW>Albanian localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
thunderbird-l10n-sq
lightning-l10n-sq
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
thunderbird-l10n-sq
lightning-l10n-sq
</uninstall_package_names>
</app>
